% reconstruct transient. invoke functions: 
% RemoveHarmonicbyMP - Remove harmonic components by multiphase imaging.
% ComplexImageRectify - Convert dumpdata to Hc and rectify.
% TransientwithLow - Compute transient image with low spectrum recovered.

addpath('..\functions')
sel_data = 20;

tau0 = 20;
tau_step = 0.1;
tau_len = 1000;
% tau0 = 20;
% tau_step = 0.01;
% tau_len = 3000;
% tau0 = 20;
% tau_step = 0.00667;
% tau_len = 3000;

%% initializing
if  ~exist('A1_pix','var')
    load('..\calib\PmCM_4_pix','A1_pix','phi1_pix');
end
%   A1, phi1: Amplitudes and phases of fundamental component
%             dimensions: frequency,0/90deg,w,h,shutter.
%   A0: DC component: frequency,0/90deg,shutter.
%   tau0: shortest flying time for each shutter.
%   lumin: illumination matrix: w,h,shuter
%   shutter shutter time.
%   freq1, freq2, freqstep, freq_len, freq: frequency setting.

%% acquaring parameters
freq1 = 5;  % MHz
freq2 = 165;
freqstep = 1; 

phs1 = 0;
phs2 = 1; % period
phs_len = 10;

w = 165;
h = 120;
shuttersz = 3;

freq = freq1:freqstep:freq2;
freq_len = length(freq);

phsstep = (phs2-phs1)/phs_len;
phs = phs1 + (0:phs_len-1)*phsstep;

sel_sh = shuttersz;

% A1 = A1(1:freq_len,:,sel_sh);
% phi1 = phi1(1:freq_len,:,sel_sh);
A1 = A1_pix(1:freq_len,:,:,:,sel_sh);
phi1 = phi1_pix(1:freq_len,:,:,:,sel_sh);

%% read data
dat = zeros(w,h,2,freq_len,phs_len);
for i = 1:freq_len
    outputpath = sprintf('scene%.2d',sel_data);
    datapath = sprintf('data_%05.1f',freq(i));
    dataname = 'meas_data_take000.dat';
    fn = sprintf('%s\\%s\\%s',outputpath,datapath,dataname);
    fprintf('reading freq %05.1f\n',freq(i));
%     rawdata = ReadDump_all(fn,phs_len,1,shuttersz,h,w);
    rawdata = ReadDump_Shutter(fn,phs_len,1,shuttersz,h,w,sel_sh);
    dat(:,:,:,i,:) = rawdata;
end

% check
showdata = false; %%%% switch %%%%
if showdata
    % show captured images
    shw = permute(dat,[2 1 4 5 3]);
    shw = shw(end:-1:1,:,:,:,:)/max(shw(:));
    for i=1:freq_len
        figure(1); 
        imagesc([shw(:,:,i,1,1) shw(:,:,i,1,2)]*256*100); 
        colormap(gray(256))
        ttl = sprintf('frequency: %d',i); title(ttl) 
        pause(0.1)
    end
end % if showdata


%% reconstruct
fprintf('\nStart Running at %s.\n',datestr(now))
tic; % atart timer

dat1 = RemoveHarmonicbyMP(dat(:,:,:,1:freq_len,:),1);

Hc1 =  ComplexImageRectify(dat1,A1,phi1);
wHc1 = Hc1;

beta = 6;
wind = kaiser(floor(freq2/freqstep)*2+1,beta);
wind = wind(end-freq_len+1:end);
for i=1:freq_len
    wHc1(:,:,i) = Hc1(:,:,i)*wind(i);
end

trans_img = TransientwithLow(wHc1,freq1,freqstep,tau0,tau_step,tau_len);
% trans_img = ComputeTransient2(Hc1,freq1,freqstep,tau0,tau_step,tau_len);

trans_iron = IronTransient3(trans_img,1,6);
% trans_iron = trans_iron/max(trans_iron(:));
% trans_iron = IronTransient3(trans_img,1,10);
% norm_img = NormalizeImage(trans_iron,2);

tElapsed = toc;
fprintf('\nRunning Time: %f\n', tElapsed)

% save(sprintf('trans%.2d',sel_data),'dat','trans_img');
save(sprintf('trans%.2d',sel_data),'trans_img');

%% plots
x = 80;
y = 60;

a = permute(dat(x,y,:,1:freq_len,1),[4 3 2 1 5]);
b = permute(dat1(x,y,:,:),[4 3 2 1]);
c = permute(Hc1(y,x,:),[3 2 1]);
tr1 = permute(trans_img(y,x,:),[3 2 1]);
tr2 = permute(trans_iron(y,x,:),[3 2 1]);

figure(1);
plot([a b real(c) imag(c)])
legend('dat_r','dat_i','dat1_r','dat1_i','Hc_{1r}','Hc_{1i}')

figure(2);
plot([tr1 tr2])

return

%% show video
% load trans16
sel_data = 16;
trans_iron = IronTransient3(trans_img,1,10);
% norm_img = NormalizeImage(trans_iron,2);
norm_img = CompressHDR(trans_iron);

i0 = 320;
i_len = 660;
for i=1:i_len
    figure(10)
%     image(trans_iron(:,:,i)*256); colormap(gray(256))
%     image(trans_img(:,:,i)*256); colormap(gray(256))
%     image(ourFrame(:,:,i)*256); colormap(gray(256))
    image(norm_img(:,:,i0+i)*256); colormap(gray(256))
    ttl = sprintf('scene %d: %.3d',sel_data,i); title(ttl)
    pause(0.02)
end
return;

%% save avi
aviname = sprintf('scene%.2d.avi',sel_data);
aviobj = avifile(aviname,'compression','none');
fig = figure(10); 
for i=1:i_len
    image(norm_img(:,:,i0+i)*256); colormap(gray(256))
    axis off
    ttl = sprintf('scene %d: %.3d',sel_data,i); title(ttl)
    F = getframe(fig);
    aviobj = addframe(aviobj,F);
end
aviobj = close(aviobj);

return

%% save png
for i=1:i_len
    fn = sprintf('scene%.2d_frame/ourFrame%.3d.png',sel_data,i); 
    imwrite(uint16(trans_iron(:,:,i0+i)*256*256),fn,'bitdepth',16);
end

